.. _services:

========
Services
========

This section describes what features are supported by the different
analytics services.  To start using a service, you can either use the
generic installation instructions (see :doc:`install`), or add
service-specific tags to your templates.

If you would like to have another analytics service supported by
django-analytical, please create an issue on the project
`issue tracker`_.  See also :ref:`helping-out`.

.. _`issue tracker`: http://github.com/jazzband/django-analytical/issues


Currently supported services:

.. toctree::
    :maxdepth: 1
    :glob:

    services/*
